<template>
  <el-dialog :close-on-click-modal="false" :title="title" :visible.sync="declareDialogVisible" width="800px"
    @close="resetFormData">
    <el-form ref="declareObj" :inline="true" :model="declareObj" :rules="declareObjRules" label-width="130px"
      label-position="right">
      <el-form-item class="declareObj-form-item" label="订单号:" prop="orderNo">
        <el-input v-model="declareObj.orderNo" class="addObj-info" clearable placeholder="" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="零件号:" prop="partNo">
        <el-input v-model="declareObj.partNo" class="addObj-info" clearable placeholder="" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="零件描述:" prop="partDesc">
        <el-input v-model="declareObj.partDesc" class="addObj-info" clearable placeholder="" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="抵达的采购数量:" prop="qtyArrived">
        <el-input v-model="declareObj.qtyArrived" class="addObj-info" clearable placeholder="" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="供应商编号:" prop="supplierId">
        <el-input v-model="declareObj.supplierId" class="addObj-info" clearable placeholder="" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="供应商名称:" prop="supplierName">
        <el-input v-model="declareObj.supplierName" class="addObj-info" clearable placeholder=""
          size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="批号:" prop="updateBatchNo">
        <el-input v-model="declareObj.updateBatchNo" class="addObj-info" clearable size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="库位号:" prop="locationNo">
        <el-input v-model="declareObj.locationNo" class="addObj-info" clearable size="small"></el-input>
      </el-form-item>
      <!-- <el-form-item class="declareObj-form-item" label="接收时间:" prop="receiverDate">
        <el-input v-model="declareObj.receiverDate" class="addObj-info" clearable disabled size="small"></el-input>
      </el-form-item> -->
      <el-form-item class="declareObj-form-item" label="单位:" prop="buyUnitMeas">
        <el-input v-model="declareObj.buyUnitMeas" clearable class="addObj-info" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="过期时间：" prop="expirationTime">
        <el-date-picker v-model="declareObj.expirationTime" type="date" placeholder="选择日期" size="small"
          format="yyyy-MM-dd" value-format="yyyy-MM-dd" style="width: 100%;">
        </el-date-picker>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="供应商批号:" prop="supplierNumber">
        <el-input v-model="declareObj.supplierNumber" clearable class="addObj-info" size="small"></el-input>
      </el-form-item>
      <el-form-item class="declareObj-form-item" label="报检类型:" prop="inspectionType">
        <el-select v-model="declareObj.inspectionType" clearable class="addObj-info" size="small" placeholder="请选择报检类型"
          disabled>
          <el-option v-for="item in dict.type.inspection_type" :key="item.value" :label="item.label"
            :value="item.value">
          </el-option>
        </el-select>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-row>
        <el-button @click="resetFormData">取 消</el-button>
        <el-button :loading="submitDeclareLoading" type="primary" @click="submitDeclare">确认报检</el-button>
      </el-row>
    </span>
  </el-dialog>
</template>

<script>
import {
  addIfsInventory
} from "@/api/business/materialInspection";
export default {
  props: ['title'],
  dicts: ["inspection_type"],
  data() {
    return {
      submitDeclareLoading: false,
      declareDialogVisible: false,
      declareObj: {},
      declareObjRules: {
        orderNo: [
          { required: false, message: '请填写订单号', trigger: 'blur' }
        ],
        partNo: [
          { required: true, message: '请填写零件号', trigger: 'blur' }
        ],
        partDesc: [
          { required: true, message: '请填写零件描述', trigger: 'blur' }
        ],
        qtyArrived: [
          { required: false, message: '请填写抵达的采购数量', trigger: 'blur' }
        ],
        supplierName: [
          { required: true, message: '请填写供应商名称', trigger: 'blur' }
        ],
        updateBatchNo: [
          { required: true, message: '请填写批号', trigger: 'blur' }
        ],
        locationNo: [
          { required: false, message: '请填写库位号', trigger: 'blur' }
        ],
        buyUnitMeas: [
          { required: false, message: '请填写单位', trigger: 'blur' }
        ],
        inspectionType: [
          { required: true, message: '请填写报检类型', trigger: 'change' }
        ],
      },
    }
  },
  methods: {
    resetFormData() {
      this.$refs['declareObj'].resetFields();
      this.declareDialogVisible = false
    },
    submitDeclare() {
      this.$refs['declareObj'].validate((valid) => {
        if (valid) {
          this.submitDeclareLoading = true
          addIfsInventory(this.declareObj).then(res => {
            this.submitDeclareLoading = false
            if (res.code === 200) {
              this.declareDialogVisible = false
              this.$message.success('提交成功')
              this.$emit('refreshTable')
            }
          }).catch(err => {
            console.log(err)
            this.submitDeclareLoading = false
          })
        } else {
          console.log('error submit!!');
          return false;
        }
      });
    },
    open(type, row) {
      if (row) {
        this.declareObj = row;
      } else {
        this.declareObj = {}
        this.declareObj.inspectionType = String(type)
      }
      this.declareDialogVisible = true
    },
  }
}
</script>

<style></style>